Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(76)

Unified Diff: runtime/vm/raw_object.h

Issue 12210127: First stab at mixins in VM compiler (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/raw_object.h
===================================================================
--- runtime/vm/raw_object.h (revision 18363)
+++ runtime/vm/raw_object.h (working copy)
@@ -433,6 +433,7 @@
RawLibrary* library_;
RawTypeArguments* type_parameters_; // Array of TypeParameter.
RawType* super_type_;
+ RawType* mixin_;
RawFunction* signature_function_; // Associated function for signature class.
RawArray* constants_; // Canonicalized values of this class.
RawArray* canonical_types_; // Canonicalized types of this class.
@@ -555,7 +556,8 @@
RawObject** from() { return reinterpret_cast<RawObject**>(&ptr()->name_); }
RawString* name_;
- RawObject* owner_; // Class or patch class where this function was defined.
+ RawObject* owner_; // Class or patch class or mixin class
+ // where this function is defined.
RawAbstractType* result_type_;
RawArray* parameter_types_;
RawArray* parameter_names_;
@@ -619,7 +621,8 @@
RawObject** from() { return reinterpret_cast<RawObject**>(&ptr()->name_); }
RawString* name_;
- RawClass* owner_;
+ RawObject* owner_; // Class or patch class or mixin class
+ // where this field is defined.
RawAbstractType* type_;
RawInstance* value_; // Offset in words for instance and value for static.
RawObject** to() { return reinterpret_cast<RawObject**>(&ptr()->value_); }
« runtime/vm/parser.cc ('K') | « runtime/vm/parser.cc ('k') | runtime/vm/token.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698